@@ -1,7 +1,7 @@
 # urwid user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2006-08 Chris Lawrence
-#   Copyright (C) 2008-2017 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -28,7 +28,7 @@ import re
 import getpass
 from reportbug.exceptions import (
     UINotImportable,
-    NoPackage, NoBugs, NoNetwork, NoReport,
+    NoPackage, NoBugs, NoReport,
 )
 from reportbug.urlutils import launch_browser
 from .text_ui import (
@@ -42,7 +42,7 @@ try:
     import urwid.raw_display
     import urwid
 except ImportError:
-    raise UINotImportable('Please install the python-urwid package to use this interface.')
+    raise UINotImportable('Please install the python3-urwid package to use this interface.')
 
 ISATTY = sys.stdin.isatty()
 
