@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2017 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -27,7 +27,7 @@ import platform
 
 try:
     import pwd
-    from .tempfiles import TempFile, tempfile_prefix, cleanup_temp_file
+    from .tempfiles import TempFile, cleanup_temp_file
 except ImportError as e:
     if platform.system() == 'Windows':
         pass
@@ -39,9 +39,10 @@ import email
 import socket
 import subprocess
 import pipes
+import apt
+import gzip
 
 from .urlutils import open_url
-from string import ascii_letters, digits
 
 # Paths for dpkg
 DPKGLIB = '/var/lib/dpkg'
@@ -92,13 +93,14 @@ fhs_directories = ['/', '/usr', '/usr/share', '/var', '/usr/X11R6',
                    '/usr/man', '/usr/doc', '/usr/bin']
 
 # A map between codenames and suites
-CODENAME2SUITE = {'wheezy': 'oldoldstable',
-                'jessie': 'oldstable',
-                'stretch': 'stable',
-                'buster': 'testing',
-                'bullseye': 'next-testing',
-                'sid': 'unstable',
-                'experimental': 'experimental'}
+CODENAME2SUITE = {'wheezy': 'oldoldoldstable',
+                  'jessie': 'oldoldstable',
+                  'stretch': 'oldstable',
+                  'buster': 'stable',
+                  'bullseye': 'testing',
+                  'bookworm': 'next-testing',
+                  'sid': 'unstable',
+                  'experimental': 'experimental'}
 SUITE2CODENAME = dict([(suite, codename) for codename, suite in list(CODENAME2SUITE.items())])
 
 
@@ -184,7 +186,7 @@ def get_command_output(cmd):
     use_shell = False
     if isinstance(cmd, str) and ' ' in cmd:
         use_shell = True
-    return subprocess.run(cmd, shell=use_shell, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).stdout.decode(errors='backslashreplace')
+    return subprocess.run(cmd, shell=use_shell, stdout=subprocess.PIPE).stdout.decode(errors='backslashreplace')
 
 
 def query_dpkg_for(filename, use_dlocate=True):
@@ -364,6 +366,13 @@ def get_package_status(package, avail=False):
         output = get_command_output(
             "LC_ALL=C.UTF-8 apt-cache show %s 2>/dev/null" % packarg)
     else:
+        # filter through dpkg-query to automatically append arch
+        # qualifier in the cases where this is needed
+        try:
+            packarg = get_command_output(
+                "dpkg-query -W -f='${binary:Package}\n' %s 2>/dev/null" % packarg).split()[0]
+        except IndexError:
+            pass
         output = get_command_output(
             "COLUMNS=79 dpkg --status %s 2>/dev/null" % packarg)
 
@@ -523,16 +532,6 @@ def get_avail_database():
     return AvailDB(popenob=subp)
 
 
-def available_package_description(package):
-    data = get_command_output('apt-cache show ' + pipes.quote(package))
-    descre = re.compile('^Description(?:-[a-zA-Z]+)?: (.*)$')
-    for line in data.split('\n'):
-        m = descre.match(line)
-        if m:
-            return m.group(1)
-    return None
-
-
 def get_source_name(package):
     packages = []
 
@@ -550,6 +549,8 @@ def get_source_package(package):
     retlist = []
     found = {}
 
+    apt_cache = apt.Cache()
+
     data = get_command_output('apt-cache showsrc ' + pipes.quote(package))
     binre = re.compile(r'^Binary: (.*)$')
     for line in data.split('\n'):
@@ -560,7 +561,10 @@ def get_source_package(package):
             packages += packlist
 
     for p in packages:
-        desc = available_package_description(p)
+        try:
+            desc = apt_cache[p].versions[0].summary
+        except KeyError:
+            continue
         if desc and (p not in found):
             retlist += [(p, desc)]
             found[p] = desc
@@ -574,7 +578,7 @@ def get_package_info(packages, skip_notfound=False):
         return []
 
     packinfo = get_dpkg_database()
-    pkgname = r'(?:[\S]+(?:$|,\s+))'
+    pkgname = r'(?:[\S]+(?:\s+\(=[^()]+\))?(?:$|,\s+))'
 
     groupfor = {}
     searchpkgs = []
@@ -582,7 +586,7 @@ def get_package_info(packages, skip_notfound=False):
     for (group, package) in packages:
         groupfor[package] = group
         escpkg = re.escape(package)
-        searchpkgs.append(escpkg)
+        searchpkgs.append(escpkg + r'(?:\s+\(=[^()]+\))?')
 
     searchbits = [
         # Package regular expression
@@ -611,13 +615,14 @@ def get_package_info(packages, skip_notfound=False):
                 sinfo = stat.split()
                 stat = sinfo[0][0] + sinfo[2][0]
                 # check if the package is installed, and in that case, retrieve
-                # its information; if the first char is not 'i' (installed) or
-                # the second is 'n' (not-installed), then skip data retrieval
-                if stat[0] != 'i' or stat[1] == 'n':
+                # its information; if the first char is not 'i' or 'h' (install
+                # or hold) or the second is 'n' (not-installed), then skip data
+                # retrieval
+                if stat[0] not in 'ih' or stat[1] == 'n':
                     continue
 
                 if m.group('hdr') == 'Provides':
-                    provides = m.group('pkg')
+                    provides = m.group('pkg').split()[0]
                 else:
                     provides = None
 
@@ -813,11 +818,12 @@ def generate_blank_report(package, pkgversion, severity, justification,
                           depinfo, confinfo, foundfile='', incfiles='',
                           system='debian', exinfo=None, type=None, klass='',
                           subject='', tags='', body='', mode=MODE_EXPERT,
-                          pseudos=None, debsumsoutput=None, issource=False):
+                          pseudos=None, debsumsoutput=None, issource=False,
+                          options=None):
     # For now...
     from . import bugreport
 
-    sysinfo = (package not in ('wnpp', 'ftp.debian.org'))
+    sysinfo = (package not in ('wnpp', 'ftp.debian.org') and (options and not options.buildd_format))
 
     # followup is where bugreport expects the notification of the bug reportbug
     # to follow-up, but reportbug pass this information with 'exinfo'
@@ -831,25 +837,6 @@ def generate_blank_report(package, pkgversion, severity, justification,
     return str(rep)
 
 
-def get_cpu_cores():
-    cpucount = 0
-    try:
-        fob = open('/proc/cpuinfo')
-    except IOError:
-        print('Unable to open /proc/cpuinfo', file=sys.stderr)
-        return 0
-
-    for line in fob:
-        if line.startswith('processor'):
-            cpucount += 1
-        # Alpha platform
-        if line.startswith('cpus detected'):
-            cpucount = int(line.split()[-1])
-    fob.close()
-
-    return max(cpucount, 1)
-
-
 class our_lex(shlex.shlex):
     def get_token(self):
         token = shlex.shlex.get_token(self)
@@ -869,7 +856,7 @@ CONFIG_ARGS = (
     'sign', 'nocc', 'nocompress', 'dontquery', 'noconf', 'mirrors', 'keyid',
     'headers', 'interface', 'template', 'mode', 'check_available', 'query_src',
     'printonly', 'offline', 'check_uid', 'smtptls', 'smtpuser', 'smtppasswd',
-    'paranoid', 'mbox_reader_cmd', 'max_attachment_size')
+    'paranoid', 'mbox_reader_cmd', 'max_attachment_size', 'listccme', 'outfile')
 
 
 class Mua:
@@ -1013,6 +1000,8 @@ def parse_config_files():
                     args['nocc'] = (token == 'no-cc')
                 elif token in ('no-compress', 'compress'):
                     args['nocompress'] = (token == 'no-compress')
+                elif token in ('no-list-cc-me', 'list-cc-me'):
+                    args['listccme'] = (token == 'list-cc-me')
                 elif token in ('no-query-bts', 'query-bts'):
                     args['dontquery'] = (token == 'no-query-bts')
                 elif token in ('config-files', 'no-config-files'):
@@ -1022,7 +1011,7 @@ def parse_config_files():
                 elif token in ('email', 'realname', 'replyto', 'http_proxy',
                                'smtphost', 'editor', 'mua', 'mta', 'smtpuser',
                                'smtppasswd', 'justification', 'keyid',
-                               'mbox_reader_cmd'):
+                               'mbox_reader_cmd', 'outfile'):
                     bit = lex.get_token()
                     args[token] = bit
                 elif token in ('no-smtptls', 'smtptls'):
@@ -1037,6 +1026,8 @@ def parse_config_files():
                         args['sign'] = ''
                 elif token == 'ui':
                     token = lex.get_token().lower()
+                    if token == 'gtk2':
+                        token = 'gtk'
                     if token in list(AVAILABLE_UIS.keys()):
                         args['interface'] = token
                 elif token == 'mode':
@@ -1237,13 +1228,13 @@ def get_running_kernel_pkg():
         return None
 
 
-def exec_and_parse_bugscript(handler, bugscript):
+def exec_and_parse_bugscript(handler, bugscript, runner=os.system):
     """Execute and parse the output of the package bugscript, in particular
     identifying the headers and pseudo-headers blocks, if present"""
 
     fh, filename = TempFile()
     fh.close()
-    rc = os.system('LC_ALL=C %s %s %s' % (handler, pipes.quote(bugscript),
+    rc = runner('LC_ALL=C %s %s %s' % (handler, pipes.quote(bugscript),
                                           pipes.quote(filename)))
 
     isheaders = False
@@ -1301,6 +1292,8 @@ def get_init_system():
         init = 'systemd (via /run/systemd/system)'
     if not subprocess.call('. /lib/lsb/init-functions ; init_is_upstart', shell=True):
         init = 'upstart (via init_is_upstart())'
+    elif os.path.isfile('/run/runit.stopit'):
+        init = 'runit (via /run/runit.stopit)'
     elif os.path.isfile('/sbin/init') and not os.path.islink('/sbin/init'):
         init = 'sysvinit (via /sbin/init)'
 
@@ -1333,3 +1326,119 @@ def get_lsm_info():
                     break
 
     return lsminfo
+
+
+def get_kernel_taint_flags():
+    """Determines the kernel taint flags"""
+
+    # https://github.com/torvalds/linux/blob/cedc5b6aab493f6b1b1d381dccc0cc082da7d3d8/include/linux/kernel.h#L582
+    # this is going to need updating (but maybe not that often)
+    TAINT_FLAGS = ['TAINT_PROPRIETARY_MODULE',
+                   'TAINT_FORCED_MODULE',
+                   'TAINT_CPU_OUT_OF_SPEC',
+                   'TAINT_FORCED_RMMOD',
+                   'TAINT_MACHINE_CHECK',
+                   'TAINT_BAD_PAGE',
+                   'TAINT_USER',
+                   'TAINT_DIE',
+                   'TAINT_OVERRIDDEN_ACPI_TABLE',
+                   'TAINT_WARN',
+                   'TAINT_CRAP',
+                   'TAINT_FIRMWARE_WORKAROUND',
+                   'TAINT_OOT_MODULE',
+                   'TAINT_UNSIGNED_MODULE',
+                   'TAINT_SOFTLOCKUP',
+                   'TAINT_LIVEPATCH',
+                   'TAINT_AUX',
+                   'TAINT_RANDSTRUCT',
+    ]
+
+    flags = []
+
+    if os.path.exists('/proc/sys/kernel/tainted'):
+        tainted = int(open('/proc/sys/kernel/tainted').read())
+
+        # tainted is an integer representing a bitmask, so logical-AND against the list of
+        # flags and if it's a TRUE, then append it to the list of flags enabled
+        for i, flag in enumerate(TAINT_FLAGS):
+            if tainted & 2**i:
+                flags.append(flag)
+
+    return flags
+
+
+def is_security_update(pkgname, pkgversion):
+    """Determine whether a given package is a security update.
+
+    Detection of security update versions works most reliably if the
+    package version under investigation is the currently installed
+    version.  If this is not the case, the probability of false
+    negatives increases.
+
+    Parameters
+    ----------
+    pkgname : str
+        package name
+    pkgversion : str
+        package version
+
+    Returns
+    -------
+    bool
+        True if there is evidence that this version is a security
+        update, otherwise False
+    """
+
+    # Check 1:
+    # If it does not follow the debXuY version number pattern, it is
+    # definitely no security update.
+    #
+    # This check is not sufficient to detect security updates reliably,
+    # since other stable updates also use the same version pattern.
+    regex = re.compile('(\+|~)deb(\d+)u(\d+)')
+    secversion = regex.search(pkgversion)
+    if not secversion:
+        return False
+
+    # Check 2:
+    # If the package comes from the Debian-Security package source, it
+    # is definitely a security update.
+    #
+    # This check does not identify all security updates, since some of
+    # them are distributed through the normal channels as part of a
+    # stable release update.
+    try:
+        p = apt.Cache()[pkgname]
+        if 'Debian-Security' in [o.label for o in
+                        p.versions[pkgversion].origins]:
+            return True
+    except:
+        pass
+
+    # Check 3:
+    # Inspect the package changelog if it mentions any vulnerability,
+    # identified by a CVE number, in the section of the latest version.
+    cl = None
+    for cl in ['/usr/share/doc/{}/changelog.Debian.gz'.format(pkgname),
+               '/usr/share/doc/{}/changelog.gz'.format(pkgname)]:
+        if os.path.exists(cl):
+            break
+
+    try:
+        with gzip.open(cl, 'rt') as f:
+            ln = f.readline()
+            if pkgversion not in ln:
+                raise KeyError
+
+            for ln in f.readlines():
+                # stop reading at the end of the first section
+                if ln.rstrip() != '' and (ln.startswith(' -- ') or not ln.startswith(' ')):
+                    break
+
+                if 'CVE-20' in ln.upper():
+                    return True
+    except:
+        pass
+
+    # guess 'no security update, but normal stable update' by default
+    return False
