@@ -1,12 +1,12 @@
 # coding=utf-8
 import unittest
+from unittest import mock
 
 from reportbug import utils
 import os.path
 import platform
 from nose.plugins.attrib import attr
 import debianbts
-import mock
 import subprocess
 
 
@@ -19,7 +19,7 @@ class TestUtils(unittest.TestCase):
 
 class TestEmail(unittest.TestCase):
     def test_check_email_addr(self):
-        real_addr = 'reportbug-maint@lists.alioth.debian.org'
+        real_addr = 'debian-reportbug@lists.debian.org'
 
         self.assertTrue(utils.check_email_addr(real_addr))
         self.assertFalse(utils.check_email_addr('dummy'))
@@ -31,15 +31,15 @@ class TestEmail(unittest.TestCase):
         self.assertFalse(utils.check_email_addr('too@many@at@signs'))
 
     def test_get_email_addr(self):
-        email = 'Reportbug Maintainers <reportbug-maint@lists.alioth.debian.org>'
+        email = 'Reportbug Maintainers <debian-reportbug@lists.debian.org>'
         name, email_addr = utils.get_email_addr(email)
 
         self.assertEqual(name, 'Reportbug Maintainers')
-        self.assertEqual(email_addr, 'reportbug-maint@lists.alioth.debian.org')
+        self.assertEqual(email_addr, 'debian-reportbug@lists.debian.org')
 
     def test_get_email(self):
         name = 'Reportbug Maintainers'
-        mail = 'reportbug-maint@lists.alioth.debian.org'
+        mail = 'debian-reportbug@lists.debian.org'
 
         n, m = utils.get_email(mail, name)
 
@@ -48,7 +48,7 @@ class TestEmail(unittest.TestCase):
 
     def test_get_user_id(self):
         name = 'Reportbug Maintainers'
-        mail = 'reportbug-maint@lists.alioth.debian.org'
+        mail = 'debian-reportbug@lists.debian.org'
         addr = utils.get_user_id(mail, name)
         self.assertEqual(addr, "%s <%s>" % (name, mail))
 
@@ -57,11 +57,11 @@ class TestEmail(unittest.TestCase):
         addr = utils.get_user_id(mail, name)
         self.assertIn(mail + '@', addr)
 
-        mail = 'Reportbug Maintainers <reportbug-maint@lists.alioth.debian.org>'
+        mail = 'Reportbug Maintainers <debian-reportbug@lists.debian.org>'
         addr = utils.get_user_id(mail)
         self.assertEqual(mail, addr)
 
-        mail = 'reportbug-maint@lists.alioth.debian.org'
+        mail = 'debian-reportbug@lists.debian.org'
         addr = utils.get_user_id(mail)
         self.assertIn(mail, addr)
 
@@ -245,16 +245,6 @@ Version: 6.6.3
                 """
         pkg = 'reportbug'
 
-        __save = subprocess.getoutput
-        subprocess.getoutput = mock.MagicMock(return_value=pkginfo % 'Description')
-        result = utils.available_package_description(pkg)
-        self.assertEqual('reports bugs in the Debian distribution', result)
-        subprocess.getoutput = mock.MagicMock(return_value=pkginfo % 'Description-en')
-        result = utils.available_package_description(pkg)
-        self.assertEqual('reports bugs in the Debian distribution', result)
-        subprocess.getoutput = __save
-        del __save
-
         __save = subprocess.getoutput
         subprocess.getoutput = mock.MagicMock(return_value=pkginfo % 'Description')
         result = utils.get_package_status(pkg)
@@ -286,13 +276,6 @@ Version: 6.6.3
         entry = next(avail_db)
         self.assertIsNotNone(entry)
 
-    def test_available_package_description(self):
-        descr = utils.available_package_description('reportbug')
-        self.assertEqual(descr, 'reports bugs in the Debian distribution')
-
-        descr = utils.available_package_description('reportbug-bugfree')
-        self.assertIsNone(descr)
-
 
 class TestSourcePackages(unittest.TestCase):
     def test_get_source_name(self):
@@ -306,7 +289,7 @@ class TestSourcePackages(unittest.TestCase):
     def test_get_source_package(self):
         src = 'reportbug'
         binpkgs = utils.get_source_package(src)
-        self.assertCountEqual([bin[0] for bin in binpkgs], ['python3-reportbug', 'reportbug'])
+        self.assertCountEqual([bin[0] for bin in binpkgs], ['python3-reportbug', 'reportbug', 'reportbug-gtk'])
 
         bin = 'python3-reportbug'
         binpkgs_frombin = utils.get_source_package(bin)
@@ -314,10 +297,6 @@ class TestSourcePackages(unittest.TestCase):
 
 
 class TestSystemInformation(unittest.TestCase):
-    def test_get_cpu_cores(self):
-        cores = utils.get_cpu_cores()
-        self.assertGreaterEqual(cores, 1)
-
     def test_lsb_release_info(self):
         res = utils.lsb_release_info()
         self.assertIn('Debian', res)
@@ -364,6 +343,7 @@ class TestSystemInformation(unittest.TestCase):
         os.path.isfile = mock.MagicMock(return_value=True)
         os.path.islink = mock.MagicMock(return_value=False)
         init = utils.get_init_system()
+        print(init)
         self.assertTrue(init.startswith('sysvinit'))
         os.path.isfile = __save1
         os.path.islink = __save2
@@ -507,7 +487,7 @@ Shell: /bin/sh linked to /bin/bash"""
                                              exinfo=123456)
         self.assertIn('Followup-For: Bug #123456', report)
 
-        bug = debianbts.get_status(123456)[0]
+        bug = debianbts.get_status([123456])[0]
         report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
                                              '', '', '', type='debbugs',
                                              exinfo=bug)
@@ -536,11 +516,11 @@ class TestConfig(unittest.TestCase):
             'debconf': False,
             'dontquery': False,
             'editor': 'emacs -nw',
-            'email': 'reportbug-maint@lists.alioth.debian.org',
-            'envelopefrom': 'reportbug-maint@lists.alioth.debian.org',
+            'email': 'debian-reportbug@lists.debian.org',
+            'envelopefrom': 'debian-reportbug@lists.debian.org',
             'headers': ['X-Reportbug-Testsuite: this is the test suite'],
             'http_proxy': 'http://proxy.example.com:3128/',
-            'interface': 'gtk2',
+            'interface': 'gtk',
             'keyid': 'deadbeef',
             'max_attachment_size': 1024000,
             'mbox_reader_cmd': 'mutt -f %s',
@@ -590,7 +570,7 @@ class TestControl(unittest.TestCase):
             utils.parse_bug_control_file(ctrl_file)
 
         self.assertEqual(submitas, 'reportbug2')
-        self.assertEqual(submitto, 'reportbug-maint@lists.alioth.debian.org')
+        self.assertEqual(submitto, 'debian-reportbug@lists.debian.org')
         self.assertIn('python', reportwith)
         self.assertIn('perl', reportwith)
         self.assertIn('python', supplemental)
